@@ -14,12 +14,31 @@ OUT_OPML = 8
 IN_OPML = 16
 IN_URL = 32
 
+EXIT = -1
+NOKEY = 0
 REFRESH_ALL = 1
 READER_NEXT = 2
 READER_PREV = 3
-ALARM = 4
+UPDATE = 4
 KEY_PASSTHRU = 5
 REDRAW_ALL = 6
 WINDOW_SWITCH = 7
+REFILTER = 8
+RETAG = 9
+TFILTER = 10
+
+STORY_SAVED = 0
+STORY_UPDATED = 1
+STORY_QD = 2
+
+PROC_UPDATE = 0
+PROC_FILTER = 1
+PROC_BOTH = 2
+PROC_TEST = 3
+PROC_GETTAGS = 4
+PROC_FLUSH = 5
+PROC_KILL = 6
+PROC_SYNC = 7
 
 VERSION_TUPLE = SET_VERSION_TUPLE
+GIT_SHA = SET_GIT_SHA
